@@ -26,7 +26,7 @@ import logging
 import datetime
 import time
 
-__version__ = '1.2.4'
+__version__ = '1.2.9'
 listenaddress = b'127.0.0.1'                       # Default listenaddress
 listenport = 10004                                 # Make sure your firewall enables you listening at this port
 # There is no need to change this if this proxy must log your data directly to the Omnik/SolarmanPV servers
@@ -311,12 +311,12 @@ class mqtt(object):
 
         self.lock.release()
 
-    def _mqtt_on_connect(self, client, userdata, flags, rc):
+    def _mqtt_on_connect(self, client, userdata, flags, rc=0):
         if rc == 0:
             logger.info("MQTT connected")
             # subscribe listening (not used)
 
-    def _mqtt_on_disconnect(self, client, userdata, flags, rc):
+    def _mqtt_on_disconnect(self, client, userdata, flags, rc=0):
         if rc == 0:
             logger.info("MQTT disconnected")
 
@@ -453,9 +453,9 @@ if __name__ == '__main__':
         args.logger_sensor_name = c.get('output.mqtt', 'logger_sensor_name', fallback=args.mqtt_logger_sensor_name)
 
         # TODO: Try to get from config from no arguments are given. Handle required parameters and defaults
-        args.serialnumber = c.getlist('proxy', 'serialnumber', fallback=args.serialnumber)
+        args.serialnumber = c.get('proxy', 'serialnumber', fallback=args.serialnumber)
         args.loglevel = c.get('proxy', 'loglevel', fallback=args.loglevel)
-        args.listenaddress = c.getint('proxy', 'listenaddress', fallback=args.listenaddress)
+        args.listenaddress = c.get('proxy', 'listenaddress', fallback=args.listenaddress)
         args.listenport = c.getint('proxy', 'listenport', fallback=args.listenport)
         args.omniklogger = c.get('proxy', 'omniklogger', fallback=args.omniklogger)
         args.omnikloggerport = c.getint('proxy', 'omnikloggerport', fallback=args.omnikloggerport)
